==> pierogi_1.1.25.tar.gz: pierogi-1.1.25/keysets/cisco.h <==
//
// cisco.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef CISCO_H
#define CISCO_H

#include "pirkeysetmetadata.h"

class QObject;

class CiscoSTB1: public PIRKeysetMetaData
{
public:
  CiscoSTB1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class CiscoSTB2: public PIRKeysetMetaData
{
public:
  CiscoSTB2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class CiscoSTB3: public PIRKeysetMetaData
{
public:
  CiscoSTB3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class CiscoSTB4: public PIRKeysetMetaData
{
public:
  CiscoSTB4(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // CISCO_H

==> pierogi_1.1.38.tar.gz: pierogi-1.1.38/keysets/cisco.h <==
//
// cisco.h
//
// Copyright 2012, 2013 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef CISCO_H
#define CISCO_H

#include "pirkeysetmetadata.h"

class QObject;
class QComboBox;

class CiscoSTB1: public PIRKeysetMetaData
{
public:
  CiscoSTB1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class CiscoSTB2: public PIRKeysetMetaData
{
public:
  CiscoSTB2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class CiscoSTB3: public PIRKeysetMetaData
{
public:
  CiscoSTB3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class CiscoSTB4: public PIRKeysetMetaData
{
public:
  CiscoSTB4(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

#endif // CISCO_H
